@@ -25,6 +25,9 @@ from core import constants
 from modules.base_module import RanaModule
 from core.signal import Signal
 
+import sys
+PYTHON3 = sys.version_info[0] > 2
+
 class DeviceModule(RanaModule):
     """A modRana device module"""
 
@@ -171,9 +174,6 @@ class DeviceModule(RanaModule):
     def enableVolumeKeys(self):
         pass
 
-    def enableVolumeKeys(self):
-        pass
-
     def hasKineticScrollingList(self):
         """report if the device provides a native kinetic scrolling list
         widget/dialog"""
@@ -187,6 +187,16 @@ class DeviceModule(RanaModule):
         """stop handling location - check handlesLocation if this is supported"""
         pass
 
+    @property
+    def profilePath(self):
+        """Return path to the main profile folder or None
+        if default path should be used.
+
+        :returns: path to the profile folder or None
+        :rtype: str or None
+        """
+        return None
+
     def getTracklogFolderPath(self):
         """return device specific tracklog folder or None if default should be used"""
         return None
@@ -207,11 +217,24 @@ class DeviceModule(RanaModule):
         """default path is handled through the options module"""
         return None
 
+    @property
+    def cacheFolderPath(self):
+        """Return path to the cache folder or None to use default"""
+        return None
+
     def needsQuitButton(self):
         """On some platforms (Android chroot) applications
         need to provide their own shutdown buttons"""
         return False
 
+    def needsBackButton(self):
+        """Some platforms (Jolla) don't need a in-UI back button"""
+        return True
+
+    def needsPageBackground(self):
+        """Some platforms (Jolla) don't need a page background"""
+        return True
+
     def handlesUrlOpening(self):
         """
         report if opening of URI is handled by the device module
@@ -235,7 +258,15 @@ class DeviceModule(RanaModule):
         """
         connected = constants.OFFLINE
         # open the /proc/net/route file
-        with open('/proc/net/route', 'rc') as f:
+        #with open('/proc/net/route', 'rc') as f:
+
+        openMode = "r"
+        if not PYTHON3:
+            openMode = "rc"
+            # TODO: check if this is still needed on Python 2.5
+            # on the N900
+            
+        with open('/proc/net/route', openMode) as f:
             for line in f:
                 # the line is delimited by tabulators
                 lineSplit = line.split('\t')
@@ -282,6 +313,18 @@ class DeviceModule(RanaModule):
         """
         return None
 
+    @property
+    def defaultTheme(self):
+        """Some platforms might need a tweaked default theme,
+        this property can be used to set it.
+
+        :returns: default theme tuple for the given platform
+        or tuple based on default theme constants if the given
+        platform has no default theme set
+        :rtype: a (theme_id, theme_name) tuple
+        """
+        return constants.DEFAULT_THEME_ID, constants.DEFAULT_THEME_NAME
+
 #  def getAutorotationSupported(self):
 #    return False
 #
