@@ -1,6 +1,7 @@
 """multi source geocoding"""
 import sys
-#import traceback
+import traceback
+
 try:  # Python 2
     from urllib import urlencode
     from urllib2 import urlopen, Request, build_opener, HTTPError, URLError
@@ -26,7 +27,7 @@ except Exception:
     import simplejson as json
 
 from core.point import Point
-
+from core import constants
 
 class GeonamesWikipediaPoint(Point):
     """
@@ -82,8 +83,8 @@ def fetchJson(query_url, params=None, headers=None):
     url = query_url + encoded_params
     print(url)
     request = Request(url, headers=headers)
-    response = urlopen(request)
-    return url, json.load(response)
+    response = urlopen(request).read().decode("utf-8")
+    return url, json.loads(response)
 
 
 def wikipediaSearch(query):
@@ -93,18 +94,16 @@ def wikipediaSearch(query):
     #            'lang':'en'
     #           }
     params = {'lang': 'en',
-              'q': query
+              'q': query,
+              'username' : constants.GEONAMES_USERNAME
     }
     try:
         url, results = fetchJson(url, params)
         return _wikipediaResults2points(results['geonames'])
     except Exception:
         import sys
-
-        e = sys.exc_info()[1]
-        #    traceback.print_exc(file=sys.stdout) # find what went wrong
         print("online: wiki search exception")
-        print(e)
+        traceback.print_exc(file=sys.stdout)
         return []
 
 
