@@ -40,7 +40,7 @@ class Options(RanaModule):
         self.keyDefault = {}
 
         # profile folder
-        self.profileFolderPath = self.modrana.getProfilePath()
+        self.profileFolderPath = self.modrana.paths.getProfilePath()
         # check the profile path and create the folders if necessary
         utils.createFolderPath(self.profileFolderPath)
 
