@@ -437,6 +437,13 @@ class Route(RanaModule):
         :param routeParams: parameters for the route search
         :type routeParams: RouteParameters object instance or None for defaults
         """
+
+        if routeParams is None:
+            routeParams = self._getDefaultRouteParameters()
+            # no custom route parameters provided, build default ones
+            # based on current settings
+
+
         providerID = self.get('routingProvider', "GoogleDirections")
         if providerID == "Monav":
             # is Monav initialized ? (lazy initialization)
@@ -474,6 +481,26 @@ class Route(RanaModule):
                 routeParams=routeParams
             )
 
+
+    def _getDefaultRouteParameters(self):
+        mode = self.get("mode", "car")
+        routeMode = constants.ROUTE_CAR
+        langCode = self.get("directionsLanguage", "en en")
+        # the (Google) language code is the second part of
+        # this whitespace delimited string
+        langCode = langCode.split(" ")[1]
+        if mode == "walk":
+            routeMode = constants.ROUTE_PEDESTRIAN
+        elif mode == "cycle":
+            routeMode = constants.ROUTE_BIKE
+        routeParams = routing_providers.RouteParameters(
+            routeMode=routeMode,
+            avoidTollRoads=self.get("routingAvoidToll", False),
+            avoidHighways=self.get("routingAvoidHighways", False),
+            language = langCode
+        )
+        return routeParams
+
     def llRoute(self, start, destination, middlePoints=None):
         if not middlePoints: middlePoints = []
 
@@ -507,7 +534,8 @@ class Route(RanaModule):
         waypoints = [start, destination]
         # specify that this route lookup should expect start and destination
         # specified as address strings
-        params = routing_providers.RouteParameters(addressRoute=True)
+        params = self._getDefaultRouteParameters()
+        params.addressRoute = True
         self.routeAsync(self._handleRoutingResultCB, waypoints, routeParams=params)
 
     def doRoute(self, waypoints):
@@ -1214,12 +1242,12 @@ class Route(RanaModule):
             menus.showText(cr, destinationText, x4 + w1 / 20, y4 + 2 * dy + dy / 5, w1 - x4 - (w1 / 20) * 2)
 
     def _geocodeStartAndDestination(self):
-        """get the address of start and destination coordinates by using geocoding"""
+        """Get the address of start and destination coordinates by using geocoding"""
         onlineModule = self.m.get('onlineServices', None)
-        connectivity = (self.modrana.dmod.getInternetConnectivityStatus() in (True, None))
+        connectivity = (self.modrana.dmod.connectivityStatus in (constants.ONLINE, constants.CONNECTIVITY_UNKNOWN))
         if connectivity and onlineModule:
             # set that address lookups are in progress
-            # (this function should be called from "inside" theaddress lookup lock)
+            # (this function should be called from "inside" the address lookup lock)
             self._startLookup = True
             self._destinationLookup = True
 
@@ -1266,12 +1294,7 @@ class Route(RanaModule):
         self.text = None
         self.set('needRedraw', True)
 
-
-
-
     def shutdown(self):
         # stop the Monav server, if running
         if self.monav:
-            self.monav.stopServer()
-  
-  
+            self.monav.stopServer()
\ No newline at end of file
